@@ -1,29 +1,14 @@
 /*
   clienttoolmanager.h
 
-  This file is part of GammaRay, the Qt application inspection and
-  manipulation tool.
+  This file is part of GammaRay, the Qt application inspection and manipulation tool.
 
-  Copyright (C) 2013-2021 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  SPDX-FileCopyrightText: 2013-2023 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
-  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
-  accordance with GammaRay Commercial License Agreement provided with the Software.
+  SPDX-License-Identifier: GPL-2.0-or-later
 
-  Contact info@kdab.com if any conditions of this licensing are not clear to you.
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  Contact KDAB at <info@kdab.com> for commercial licensing options.
 */
 
 #ifndef GAMMARAY_CLIENTTOOLMANAGER_H
@@ -34,6 +19,7 @@
 #include <QHash>
 #include <QPointer>
 #include <QVector>
+#include <QObject>
 
 QT_BEGIN_NAMESPACE
 class QAbstractItemModel;
@@ -109,7 +95,7 @@ public:
     void requestToolsForObject(const ObjectId &id);
     void selectObject(const ObjectId &id, const ToolInfo &toolInfo);
 
-    static ClientToolManager* instance();
+    static ClientToolManager *instance();
 
 public slots:
     void requestAvailableTools();
@@ -133,7 +119,7 @@ private slots:
     void toolsForObjectReceived(const GammaRay::ObjectId &id, const QVector<QString> &toolIds);
 
 private:
-    typedef QHash<QString, QPointer<QWidget> > WidgetsHash;
+    typedef QHash<QString, QPointer<QWidget>> WidgetsHash;
     mutable WidgetsHash m_widgets; // ToolId -> Widget
     QVector<ToolInfo> m_tools;
     QPointer<ToolManagerInterface> m_remote;
